- 8d16b3a Update pyproject.toml (Dinesh Ravi, 2025-07-14)
- 0107c2c Update README.md (Dinesh Ravi, 2025-07-14)
- 4b1d89c update to 0.1.1 (Dinesh Ravi, 2025-07-14)
- c180117 Update README.md (Dinesh Ravi, 2025-07-14)
- e905a5a updated readme (Dinesh, 2025-07-14)
- 5a9d3fa all license screenshot (Dinesh, 2025-07-14)
- d2a2d99 improve change log (Dinesh, 2025-07-14)
- 5568ec7 add screenshots (Dinesh, 2025-07-14)
- 6227d95 update changelog (Dinesh, 2025-07-14)
- f943e59 first commit (Dinesh, 2025-07-14)